pub enum ExecuteMsg {
Bond {
vesting_tokens: Option<Coin>,
},
Unbond {
tokens: Coin,
},
Claim {},
UpdateAdmin {
admin: Option<String>,
},
AddHook {
addr: String,
},
RemoveHook {
addr: String,
},
AddSlasher {
addr: String,
},
RemoveSlasher {
addr: String,
},
Slash {
addr: String,
portion: Decimal,
},
}Variants
Bond
Bond will bond all staking tokens sent with the message and update membership points.
The optional vesting_tokens will be staked (delegated) as well, if set.
Unbond
Unbond will start the unbonding process for the given number of tokens.
The sender immediately loses points from these tokens, and can claim them
back to his wallet after unbonding_period.
Tokens will be unbonded from the liquid stake first, and then from the vesting stake
if available.
Claim
Claim is used to claim your native and vesting tokens that you previously “unbonded” after the contract-defined waiting period (eg. 1 week)
UpdateAdmin
Change the admin
AddHook
Add a new hook to be informed of all membership changes. Must be called by Admin
RemoveHook
Remove a hook. Must be called by Admin
AddSlasher
Add a new slasher. Must be called by Admin
RemoveSlasher
Remove a slasher. Must be called by Admin
Slash