pub enum QueryMsg {
Show 13 variants
Configuration {},
Claims {
address: String,
limit: Option<u32>,
start_after: Option<Expiration>,
},
Staked {
address: String,
},
UnbondingPeriod {},
Admin {},
TotalPoints {},
ListMembers {
start_after: Option<String>,
limit: Option<u32>,
},
ListMembersByPoints {
start_after: Option<Member>,
limit: Option<u32>,
},
Member {
addr: String,
at_height: Option<u64>,
},
Hooks {},
Preauths {},
IsSlasher {
addr: String,
},
ListSlashers {},
}Variants
Configuration
Returns config
Claims
Claims shows the tokens in process of unbonding for this address
Staked
Shows the number of liquid and vesting tokens currently staked by this address. Returns StakedResponse.
UnbondingPeriod
Returns the unbonding period of this contract. Returns UnbondingPeriodResponse.
Admin
Return AdminResponse
TotalPoints
Returns TotalPointsResponse. This is the amount of tokens bonded divided by tokens_per_point.
ListMembers
Returns MemberListResponse
ListMembersByPoints
Returns MemberListResponse, sorted by points descending.
Member
Returns MemberResponse
Hooks
Shows all registered hooks. Returns HooksResponse.
Preauths
Return the current number of preauths. Returns PreauthResponse.
IsSlasher
Returns information (bool) about whether a given address is an active slasher
ListSlashers
Returns all active slashers as a vector of addresses.