pub struct UnbondingPeriodResponse {
pub unbonding_period: Duration,
}Fields
unbonding_period: DurationTrait Implementations
Sourceimpl Clone for UnbondingPeriodResponse
impl Clone for UnbondingPeriodResponse
Sourcefn clone(&self) -> UnbondingPeriodResponse
fn clone(&self) -> UnbondingPeriodResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnbondingPeriodResponse
impl Debug for UnbondingPeriodResponse
Sourceimpl<'de> Deserialize<'de> for UnbondingPeriodResponse
impl<'de> Deserialize<'de> for UnbondingPeriodResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for UnbondingPeriodResponse
Sourceimpl JsonSchema for UnbondingPeriodResponse
impl JsonSchema for UnbondingPeriodResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for UnbondingPeriodResponse
impl PartialEq for UnbondingPeriodResponse
Sourceimpl Serialize for UnbondingPeriodResponse
impl Serialize for UnbondingPeriodResponse
impl StructuralPartialEq for UnbondingPeriodResponse